@@ -36,6 +36,18 @@ MAX_MSG_LEN = 65535
 
 
 class message:
+    """
+    Class for a message
+
+    Attributes:
+        error: Error state of the message
+        msg_type: Type of the message
+        src_addr: Source address of the message (sender)
+        tgt_addr: Target address of the message (receiver)
+        msg_len: Length of the message payload in bytes
+        msg_payload: Payload of the message
+        msg_crc: CRC of the message
+    """
     error = error_state.NO_ERROR
     msg_type = 0
     src_addr = 0
@@ -44,8 +56,18 @@ class message:
     msg_payload = []
     msg_crc = 0
 
-    def __init__(self, msg_type, src_addr, tgt_addr, msg_len, msg_payload,
-                 msg_crc):
+    def __init__(self, msg_type, src_addr, tgt_addr, msg_len, msg_payload, msg_crc):
+        """
+        Constructor for the message class
+
+        Args:
+            msg_type: Type of the message
+            src_addr: Source address of the message (sender)
+            tgt_addr: Target address of the message (receiver)
+            msg_len: Length of the message payload in bytes
+            msg_payload: Payload of the message
+            msg_crc: CRC of the message
+        """
         self.error = error_state.NO_ERROR
         self.msg_type = msg_type
         self.src_addr = src_addr
@@ -55,11 +77,23 @@ class message:
         self.msg_crc = msg_crc
 
     def __str__(self):
+        """
+        String representation of the message class
+
+        Returns:
+            String representation of the message class
+        """
         return "msg_type: {}, src_addr: {}, tgt_addr: {}, msg_len: {}, msg_payload: {}, msg_crc: {}, error: {}".format(
             hex(self.msg_type), hex(self.src_addr), hex(self.tgt_addr),
             hex(self.msg_len), self.msg_payload, hex(self.msg_crc), self.error)
 
     def to_list(self):
+        """
+        Convert the message to a list of bytes
+
+        Returns:
+            List of bytes representing the message
+        """
         msg_list = []
         msg_list.append(HEADER_BYTE0)
         msg_list.append(HEADER_BYTE1)
@@ -89,12 +123,25 @@ message_available = False
 
 # Set my address
 def set_my_address(addr):
+    """
+    Set the address of the current device.
+
+    Args:
+        addr: Address of the current device
+    """
     global my_addr
     my_addr = addr
 
 
 # Internal notify of a parsed message
 def notify_parsed_message(msg):
+    """
+    Notify the user that a message has been parsed, and store the message in the parsed_message_queue list.
+    Sets the message_available global variable to True.
+
+    Args:
+        msg: Message that has been parsed
+    """
     global parsed_message_queue
     global message_available
     parsed_message_queue.append(msg)
@@ -103,6 +150,12 @@ def notify_parsed_message(msg):
 
 # Calculate the CRC of the message
 def calculate_crc(msg):
+    """
+    Calculate the CRC of the message.
+
+    Args:
+        msg: Message to calculate the CRC of
+    """
     crc = 0xFFFF
     byte_list = []
     byte_list.append(HEADER_BYTE0)
@@ -128,6 +181,11 @@ def calculate_crc(msg):
 
 # Reset the parsing state machine
 def reset_parsing_state():
+    """
+    Reset the parsing state machine. Sets the p_state global variable to HEADER_POS0. 
+    Sets the current_msg global variable to a new message. If a message is successfully parsed, 
+    this method will call notify_parsed_message.
+    """
     global p_state
     global current_msg
     p_state = parsing_state.HEADER_POS0
@@ -136,6 +194,13 @@ def reset_parsing_state():
 
 # Parse the incoming byte in the state machine
 def parse_byte(byte):
+    """
+    Parse the incoming byte in the state machine. Sets the p_state global variable to the next state. 
+    Sets the current_msg global variable to the parsed message as it becomes parsed.
+
+    Args:
+        byte: Byte to parse from the incoming byte stream.
+    """
     global p_state
     global current_msg
     # Switch based on the state
@@ -198,6 +263,12 @@ def parse_byte(byte):
 
 # Parse an incoming list of bytes into the state machine
 def parse_input_buffer(input_buffer):
+    """
+    Parse an incoming list of bytes into the state machine. This message simply takes a list and calls parse_byte on each byte.
+
+    Args:
+        input_buffer: List of bytes to parse.
+    """
     try:
         # Parse the input buffer into the state machine
         for byte in input_buffer:
@@ -208,6 +279,12 @@ def parse_input_buffer(input_buffer):
 
 # Check for parsed messages in the queue
 def check_for_parsed_messages():
+    """
+    Check for parsed messages in the queue. Returns a list of parsed messages. If no messages are available, returns an empty list.
+
+    Returns:
+        List of parsed messages.
+    """
     global parsed_message_queue
     global message_available
     if message_available:
@@ -221,6 +298,17 @@ def check_for_parsed_messages():
 
 # Send a message to the message handler
 def build_message(type, addr, payload):
+    """
+    Build a message to send to the message handler. This method will calculate the CRC and return the message.
+
+    Args:
+        type: Message type.
+        addr: Target address of the message.
+        payload: Payload of the message.
+
+    Returns:
+        Message to send to the message handler.
+    """
     # Check for null payload
     if payload is None:
         payload = []
@@ -240,4 +328,10 @@ def build_message(type, addr, payload):
 
 # Get the version information from the library
 def get_version():
+    """
+    Get the version information from the library.
+
+    Returns:
+        Tuple of the major, minor, and revision version numbers.
+    """
     return ver.VERSION_MAJOR, ver.VERSION_MINOR, ver.VERSION_REV
